<?php

declare(strict_types=1);
namespace App\Controller;

use App\JsonRpc\FormServiceInterface;
use Hyperf\Di\Annotation\Inject;
use Hyperf\HttpServer\Annotation\AutoController;
use App\Tools\Result;
use Hyperf\Validation\Contract\ValidatorFactoryInterface;
use App\Constants\ErrorCode;
use Hyperf\Context\Context;
use App\Service\ImportQueueService;
/**
 * ClassFormController
 * @package App\Controller
 */

class FormController extends AbstractController
    {
    #[Inject]
    protected ValidatorFactoryInterface $validationFactory;

    #[Inject]
    protected ImportQueueService $Iservice;

    /**
     * @var FormServiceInterface
     */
    #[Inject]
    private $formServiceClient;
 
    /**
     * 添加网站
     * @return array
     */
    public function addGlobalTable()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'website_id'=> 'required',
                'name'=> 'required',
                'table'=> 'required',
            ],
            [
                'website_id.required' => '网站ID不能为空',
                'name.required' => '表单名称不能为空',
                'table.required' => '表单表名不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }


        
        $result = $this->formServiceClient->addGlobalTable($requireData);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);
    }
    /**
     * 全局表单列表
     * @return array
     */
    public function getGlobalTableList()    
    {
        $requireData = $this->request->all();   
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'page'=> 'required',
                'pageSize'=> 'required',
            ],
            [
                'page.required' => '页码不能为空',
                'pageSize.required' => '每页显示条数不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->formServiceClient->getGlobalTableList($requireData);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);
    }
    /**
     * 修改全局表单
     */
    public function upGlobalTable()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'website_id'=> 'required',
                'name'=> 'required',
                'table'=> 'required',
                'id'=> 'required',
            ],
            [
                'website_id.required' => '网站ID不能为空',
                'name.required' => '表单名称不能为空',
                'table.required' => '表单表名不能为空',
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->formServiceClient->upGlobalTable($requireData);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);
    }
    /** 
     * 删除全局表单
    */
    public function delGlobalTable()
    {
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=> 'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->formServiceClient->delGlobalTable($requireData);
        if ($result['code'] != ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);
    }
    /**
     * 获取全局表单详情
     * @return array
     */
    public function getGlobalTable(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->formServiceClient->getGlobalTable($requireData);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);
    }
    /**
     * 获取表单下面的-字段
     * @return array
     */
    public function getGlobalTableFieldList(){

        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);    
        }
        $result = $this->formServiceClient->getGlobalTableFieldList($requireData);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);
    }
    /**
     * 添加字段
     * @return array
     */
    public function addGlobalTableField(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'title'=>'required',
                'field_name'=>'required',
                'field_type'=>'required',
                'table_id'=>'required',
            ],
            [
                'title.required' => '显示名称不能为空',
                'field_name.required' => '字段名称不能为空',
                'field_type.required' => '字段类型不能为空',
                'table_id.required' => '表单id不能为空',        

            ]
            );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);    
        }
        $result = $this->formServiceClient->addGlobalTableField($requireData);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);
    }
    /**
     * upGlobalTableField
     * @return array
     */
    public function upGlobalTableField(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
                'title'=>'required',
                'field_name'=>'required',
                'field_type'=>'required',
                'table_id'=>'required',
            ],
            [
                'id.required' => 'id不能为空',
                'title.required' => '显示名称不能为空',
                'field_name.required' => '字段名称不能为空',        
                'field_type.required' => '字段类型不能为空',
            ]
            );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->formServiceClient->upGlobalTableField($requireData);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }   
        return Result::success($result['data']);
    }
    /**
     * 删除表单字段
     * @return array
     */
    public function delGlobalTableField(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
            );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->formServiceClient->delGlobalTableField($requireData);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);

    }
    /**
     * 获取表单字段详情
     * @return array    
     */
    public function getGlobalTableField(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
            );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();  
            return Result::error($errorMessage);
        }
        $result = $this->formServiceClient->getGlobalTableField($requireData);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);
    }
    /**
     * 查看表单下面的数据
     * getGlobalTableData
     * @return array
     */
    public function getGlobalTableData(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
            ],
            [
                'id.required' => 'id不能为空',
            ]
            );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->formServiceClient->getGlobalTableData($requireData);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);
    }
    /**
     * 字段类型列表
     * @return array
     */
    public function getGlobalTableFieldTypeList(){
        $result = $this->formServiceClient->getGlobalTableFieldTypeList([]);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);
    }

    /**
     * 删除表单下面的数据
     * @return array
     */
    public function delGlobalTableData(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
                'table_id'=>'required',
            ],
            [
                'id.required' => 'id不能为空',
                'table_id.required' => '表单id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->formServiceClient->delGlobalTableData($requireData);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);
    }

    /**
     * @return array
     */
    public function getGlobalTableDataById(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
                'table_id'=>'required',
            ],
            [
                'id.required' => 'id不能为空',
                'table_id.required' => '表单id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->formServiceClient->getGlobalTableDataById($requireData);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);
    }

    /**
     * 更新表单下面的数据
     * @return array
     */
    public function updateGlobalTableData(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'id'=>'required',
                'table_id'=>'required',
            ],
            [
                'id.required' => 'id不能为空',
                'table_id.required' => '表单id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->formServiceClient->updateGlobalTableData($requireData);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);
    }

    /**、
     * 拉取字段
     * @return array
     */
    public function getWebGlobalTableFieldList(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'table_id'=>'required',
            ],
            [
                'table_id.required' => '表单id不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $result = $this->formServiceClient->getWebGlobalTableFieldList($requireData);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);
    }

    /**
     * 存储数据
     * @return array
     */
    public function addWebGlobalTableData(){
        $requireData = $this->request->all();
        $validator = $this->validationFactory->make(
            $requireData,
            [
                'data'=>'required',
                'otherData'=>'required',
            ],
            [
                'data.required' => '数据不能为空',
                'otherData.required' => '数据不能为空',
            ]
        );
        if ($validator->fails()) {
            $errorMessage = $validator->errors()->first();
            return Result::error($errorMessage);
        }
        $requireData['orderData']['website_id'] = Context::get('SiteId');
        $result = $this->formServiceClient->addWebGlobalTableData($requireData);
        if ($result['code']!= ErrorCode::SUCCESS) {
            return Result::error($result['message'],0,[]);
        }
        return Result::success($result['data']);
    }
}